@@ -9,6 +9,8 @@
 """
 import datetime
 import time
+import json
+import requests
 from dateutil.relativedelta import relativedelta
 
 
@@ -208,6 +210,14 @@ def monitoring_run_time(f):
         return res
     return wrapper
 
+def get_taobao_time():
+    """获取苏宁时间"""
+    url = 'http://quan.suning.com/getSysTime.do'
+    ts = requests.get(url)
+    if ts.status_code == 200:
+        json_data = json.loads(ts.text)
+        return json_data
 if __name__ == '__main__':
     month_begin_day = month_datelist('2020-01')
     print(getdate(1))
+    get_taobao_time()
